@@ -1,5 +1,5 @@
 package Test::Count::FileMutator::ByFileType::Lib;
-$Test::Count::FileMutator::ByFileType::Lib::VERSION = '0.1001';
+$Test::Count::FileMutator::ByFileType::Lib::VERSION = '0.1100';
 use strict;
 use warnings;
 
@@ -102,7 +102,7 @@ __END__
 
 =head1 VERSION
 
-version 0.1001
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -179,7 +179,7 @@ L<http://www.opensource.org/licenses/mit-license.php>
 
 Copyright by Shlomi Fish, 2009.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -216,14 +216,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Count>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Test-Count>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -295,7 +287,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2006 by Shlomi Fish.
 
 This is free software, licensed under:
 
