@@ -1,5 +1,5 @@
 package Test::Count::Filter::ByFileType::App;
-$Test::Count::Filter::ByFileType::App::VERSION = '0.1001';
+$Test::Count::Filter::ByFileType::App::VERSION = '0.1100';
 use strict;
 use warnings;
 
@@ -56,7 +56,7 @@ __END__
 
 =head1 VERSION
 
-version 0.1001
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -129,7 +129,7 @@ Copyright 2009 Shlomi Fish.
 
 This program is released under the following license: MIT X11.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -166,14 +166,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Test-Count>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Test-Count>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -245,7 +237,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2018 by Shlomi Fish.
+This software is Copyright (c) 2006 by Shlomi Fish.
 
 This is free software, licensed under:
 
